"""
VenusAI: A Python package for building powerful AI agents.
"""

__author__ = "Mert Sırakaya"
__maintainer__ = "https://github.com/fswair"
__email__ = "contact@tomris.dev"
__version__ = "0.0.1"
__license__ = "MIT"

import this


from setuptools import setup

setup(
    name='VenusAI',
    version='0.0.1',
    author='Mert Sırakaya',
    maintainer='fswair',
    maintainer_email='contact@tomris.dev',
    description='A Python package for building powerful AI agents.',
    url='https://github.com/fswair/VenusAI',
    packages=['VenusAI'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12'
    ],
    python_requires='>=3.10',
)
    
